@@ -2,6 +2,20 @@
 ###
 ### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 
 lmList <-
   ## a list of lm objects from a formula or a groupedData object
@@ -767,7 +781,7 @@ plot.lmList <-
                                 cex = dots$cex, adj = dots$adj)
                       }
 		      if (!is.null(abl)) {
-			panel.abline(abl, ...)
+			if (length(abl) == 2) panel.abline(a = abl, ...) else panel.abline(h = abl, ...)
 		      }
 		    }))
     } else {				# assume factor or character
