@@ -1,27 +1,26 @@
 /*
-Routines for calculation of the log-likelihood or restricted
-log-likelihood with mixed-effects models.
+   Routines for calculation of the log-likelihood or restricted
+   log-likelihood with mixed-effects models.
 
-Copyright 1997-2005  Douglas M. Bates <bates@stat.wisc.edu>,
-Jose C. Pinheiro <jose.pinheiro@pharma.novartis.com>
-Saikat DebRoy <saikat@stat.wisc.edu>
+   Copyright 1997-2005  Douglas M. Bates <bates@stat.wisc.edu>,
+   Jose C. Pinheiro <jose.pinheiro@pharma.novartis.com>
+   Saikat DebRoy <saikat@stat.wisc.edu>
 
-This file is part of the nlme library for R and related languages
-and is made available under the terms of the GNU General Public
-License, version 2, or at your option, any later version,
-incorporated herein by reference.
+   This file is part of the nlme package for R and related languages
+   and is made available under the terms of the GNU General Public
+   License, version 2, or at your option, any later version,
+   incorporated herein by reference.
 
-This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the GNU General Public License for more
-details.
+   This program is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied
+   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+   PURPOSE.  See the GNU General Public License for more
+   details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, a copy is available at
+   http://www.r-project.org/Licenses/
 
-You should have received a copy of the GNU General Public
-License along with this program; if not, write to the Free
-Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA
- 
 */
 
 #include "nlmefit.h"
